Crate op_alloy_consensus

Crate op_alloy_consensus 

op-alloy-consensus

CI op-alloy-consensus crate MIT License Apache License Book

Optimism consensus interface.

This crate contains constants, types, and functions for implementing Optimism EL consensus and communication. This includes an extended OpTxEnvelope type with deposit transactions, and receipts containing OP Stack specific fields (deposit_nonce + deposit_receipt_version).

In general a type belongs in this crate if it exists in the alloy-consensus crate, but was modified from the base Ethereum protocol in the OP Stack. For consensus types that are not modified by the OP Stack, the alloy-consensus types should be used instead.

Provenance

Much of this code was ported from reth-primitives as part of ongoing alloy migrations.

Re-exports

pub use transaction::DEPOSIT_TX_TYPE_ID;
pub use transaction::DepositTransaction;
pub use transaction::OpPooledTransaction;
pub use transaction::OpTransaction;
pub use transaction::OpTxEnvelope;
pub use transaction::OpTxType;
pub use transaction::OpTypedTransaction;
pub use transaction::TxDeposit;
pub use eip1559::EIP1559ParamError;
pub use eip1559::decode_eip_1559_params;
pub use eip1559::decode_holocene_extra_data;
pub use eip1559::decode_jovian_extra_data;
pub use eip1559::encode_holocene_extra_data;
pub use eip1559::encode_jovian_extra_data;
pub use predeploys::L2_TO_L1_MESSAGE_PASSER_ADDRESS;

Modules

eip1559
Support for EIP-1559 parameters after holocene.
interop
Commonly used types for interop.
predeploys
Addresses of OP Stack pre-deployed contracts.
transaction
Transaction types for Optimism.

Structs

InteropBlockReplacementDepositSource
An interop block replacement deposit transaction source.
L1InfoDepositSource
A L1 info deposit transaction source.
OpDepositReceipt
Receipt containing result of transaction execution.
UpgradeDepositSource
An upgrade deposit transaction source.
UserDepositSource
A deposit transaction source.

Enums

DepositSourceDomain
Source domains for deposit transactions.
DepositSourceDomainIdentifier
Source domain identifiers for deposit transactions.
OpReceipt
Typed Optimism transaction receipt.
OpReceiptEnvelope
Receipt envelope, as defined in EIP-2718, modified for OP Stack chains.

Traits

OpTxReceipt
Receipt is the result of a transaction execution.

Type Aliases

OpBlock
An Optimism block type.
OpDepositReceiptWithBloom
OpDepositReceipt with calculated bloom filter, modified for the OP Stack.